class XfersError(Exception):

    def __init__(self, message=None, http_status=None):
        self.message = message
        self.http_status = http_status

    def __str__(self):
        return "{} ---- Body: {}\t Code: {}".format(type(self).__name__, self.message, self.http_status)


class InvalidRequestError(XfersError):
    pass


class AuthenticationError(XfersError):
    pass


class InternalServerError(XfersError):
    pass



from xfers import api_resource
from xfers import error


RESOURCE_URL = '/cards'


def list_all(user_api_token):
    params = {'user_api_token': user_api_token}
    return api_resource.get(params, RESOURCE_URL, None)


def add(params):
    if not params:
        raise error.InvalidRequestError("Params cannot be empty", 400)
    return api_resource.post(params, RESOURCE_URL, None)


def delete(card_id, user_api_token):
    if not card_id:
        raise error.InvalidRequestError("Card id cannot be empty", 400)
    if not user_api_token:
        raise error.InvalidRequestError("user_api_token cannot be empty", 400)
    params = {'user_api_token': user_api_token}
    return api_resource.delete('{}/{}'.format(RESOURCE_URL, card_id), None, params)


def set_default(card_id, user_api_token):
    if not card_id:
        raise error.InvalidRequestError("Card id cannot be empty", 400)
    if not user_api_token:
        raise error.InvalidRequestError("user_api_token cannot be empty", 400)
    params = {'user_api_token': user_api_token}
    return api_resource.post(params, '{}/{}/set_default'.format(RESOURCE_URL, card_id), None)


def charge_guest(params):
    if not params:
        raise error.InvalidRequestError("Params cannot be empty", 400)
    return api_resource.post(params, '/credit_card_charges/charge_card_guest', None)


def charge_existing(card_id):
    if not card_id:
        raise error.InvalidRequestError("Card id cannot be empty", 400)
    params = {'txn_id': card_id}
    return api_resource.post(params, '/credit_card_charges/charge_card', None)



from xfers import api_resource
from xfers import error


RESOURCE_URL = '/intents'


def retrieve(connect_key=None):
    return api_resource.get(None, RESOURCE_URL, connect_key)


def create(params, connect_key=None):
    if not params:
        raise error.InvalidRequestError("Params cannot be empty", 400)
    return api_resource.post(params, RESOURCE_URL, connect_key)


def cancel(intent_id, connect_key=None):
    if not intent_id:
        raise error.InvalidRequestError("Intent id cannot be empty", 400)
    return api_resource.post(None, '{}/{}/cancel'.format(RESOURCE_URL, intent_id), connect_key)



import os
import sys
import warnings

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

try:
    from distutils.command.build_py import build_py_2to3 as build_py
except ImportError:
    from distutils.command.build_py import build_py

path, script = os.path.split(sys.argv[0])
os.chdir(os.path.abspath(path))

install_requires = []

if sys.version_info < (2, 6):
    warnings.warn(
        'Python 2.5 is no longer officially supported by Xfers. '
        'If you have any questions, please file an issue on Github or '
        'contact us at support@xfers.io.',
        DeprecationWarning)
    install_requires.append('requests >= 0.8.8, < 0.10.1')
else:
    install_requires.append('requests >= 2.5.4')

# Don't import xfers module here, since deps may not be installed
sys.path.insert(0, os.path.join(os.path.dirname(__file__), 'xfers'))

setup(
    name='xfers',
    cmdclass={'build_py': build_py},
    version='1.2.0',
    description='Xfers python bindings',
    author='Xfers',
    author_email='support@xfers.io',
    url='https://github.com/Xfers/xfers-python',
    packages=['xfers'],
    install_requires=install_requires,
    keywords=['payments', 'xfers'],
    license='MIT',
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Software Development :: Libraries :: Python Modules"
    ]
)